@@ -8,12 +8,13 @@
 
 QIcon Common::getIcon(const QString &iconName)
 {
+    // qDebug() << "Common::getIcon called with iconName:" << iconName;
     return QIcon::fromTheme("dm_" + iconName);
 }
 
 int Common::getLabelAdjustHeight(const int &width, const QString &text, const QFont &font)
 {
-    qDebug() << "Calculating label height for text:" << text.left(20) << "...";
+    // qDebug() << "Calculating label height for text:" << text.left(20) << "...";
     DLabel label;
     label.setFont(font);
     label.setWordWrap(true);
@@ -22,6 +23,6 @@ int Common::getLabelAdjustHeight(const int &width, const QString &text, const QF
     label.adjustSize();
 
     int height = label.height();
-    qDebug() << "Calculated label height:" << height;
+    // qDebug() << "Calculated label height:" << height;
     return height;
 }
