@@ -116,18 +116,21 @@ void DiskHealthDetectionDialog::initUI()
     DPalette paletteStateColor;
 
     if (0 == healthStateValue.compare("PASSED", Qt::CaseInsensitive) || 0 == healthStateValue.compare("OK", Qt::CaseInsensitive)) {
+        qDebug() << "Health status is PASSED or OK.";
         iconHealth = Common::getIcon("good");
         iconHealthLabel->setPixmap(iconHealth.pixmap(30, 30));
         m_healthStateValue->setText(tr("Good")); // 良好    【警告】Warning
         paletteStateColor.setColor(DPalette::Text, QColor("#00c800"));
         m_healthStateValue->setPalette(paletteStateColor);
     } else if (0 == healthStateValue.compare("Failure", Qt::CaseInsensitive)) {
+        qDebug() << "Health status is Failure.";
         iconHealth = Common::getIcon("damage");
         iconHealthLabel->setPixmap(iconHealth.pixmap(30, 30));
         m_healthStateValue->setText(tr("Damaged")); // 损坏
         paletteStateColor.setColor(DPalette::Text, QColor("#E02020"));
         m_healthStateValue->setPalette(paletteStateColor);
     } else {
+        qDebug() << "Health status is Unknown.";
         iconHealth = Common::getIcon("unknown");
         iconHealthLabel->setPixmap(iconHealth.pixmap(30, 30));
         m_healthStateValue->setText(tr("Unknown")); // 未知
@@ -226,14 +229,17 @@ void DiskHealthDetectionDialog::initUI()
 //    m_tableView->setColumnWidth(6, 186);
 
     for (int i = 0; i < m_hardDiskStatusInfoList.count(); i++) {
+        // qDebug() << "Processing hard disk status info at index:" << i;
         HardDiskStatusInfo hardDiskStatusInfo = m_hardDiskStatusInfoList.at(i);
 
         if (hardDiskStatusInfo.m_id == "194" || hardDiskStatusInfo.m_attributeName == "Temperature") {
+            // qDebug() << "Found temperature related attribute (ID 194 or Name Temperature).";
             QString value;
             for (int i = 0; i < hardDiskStatusInfo.m_rawValue.size(); i++) {
                 if (hardDiskStatusInfo.m_rawValue.at(i) >= "0" && hardDiskStatusInfo.m_rawValue.at(i) <= "9") {
                     value += hardDiskStatusInfo.m_rawValue.at(i);
                 } else {
+                    qDebug() << "Non-digit character encountered in raw temperature value, breaking loop.";
                     break;
                 }
             }
@@ -247,56 +253,73 @@ void DiskHealthDetectionDialog::initUI()
         QList<QStandardItem*> itemList;
 
         if (!hardDiskStatusInfo.m_id.isEmpty()) {
+            // qDebug() << "Hard disk status ID is not empty, adding ID:" << hardDiskStatusInfo.m_id << "to item list.";
             itemList << new QStandardItem(hardDiskStatusInfo.m_id);
         } else {
+            // qDebug() << "Hard disk status ID is empty, adding empty ID item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_whenFailed.isEmpty()) {
             if (hardDiskStatusInfo.m_whenFailed == "-") {
+                // qDebug() << "Hard disk status whenFailed is '-', setting status to 'G'.";
                 itemList << new QStandardItem("G");
             } else if(0 == hardDiskStatusInfo.m_whenFailed.compare("In_the_past", Qt::CaseInsensitive)) {
+                // qDebug() << "Hard disk status whenFailed is 'In_the_past', setting status to 'W'.";
                 itemList << new QStandardItem("W");
             } else if(0 == hardDiskStatusInfo.m_whenFailed.compare("FAILING_NOW", Qt::CaseInsensitive)) {
+                // qDebug() << "Hard disk status whenFailed is 'FAILING_NOW', setting status to 'D'.";
                 itemList << new QStandardItem("D");
             } else {
+                // qDebug() << "Hard disk status whenFailed is unknown, setting status to 'U'.";
                 itemList << new QStandardItem("U");
             }
         } else {
+            // qDebug() << "Hard disk status whenFailed is empty, adding empty status item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_value.isEmpty()) {
+            // qDebug() << "Hard disk status value:" << hardDiskStatusInfo.m_value << "is not empty, adding value to item list.";
             itemList << new QStandardItem(hardDiskStatusInfo.m_value);
         } else {
+            // qDebug() << "Hard disk status value is empty, adding empty value item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_worst.isEmpty()) {
+            // qDebug() << "Hard disk status worst:" << hardDiskStatusInfo.m_worst << "is not empty, adding worst to item list.";
             itemList << new QStandardItem(hardDiskStatusInfo.m_worst);
         } else {
+            // qDebug() << "Hard disk status worst is empty, adding empty worst item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_thresh.isEmpty()) {
+            // qDebug() << "Hard disk status thresh:" << hardDiskStatusInfo.m_thresh << "is not empty, adding thresh to item list.";
             itemList << new QStandardItem(hardDiskStatusInfo.m_thresh);
         } else {
+            // qDebug() << "Hard disk status thresh is empty, adding empty thresh item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_rawValue.isEmpty()) {
+            // qDebug() << "Hard disk status rawValue:" << hardDiskStatusInfo.m_rawValue << "is not empty, adding rawValue to item list.";
             itemList << new QStandardItem(hardDiskStatusInfo.m_rawValue);
         } else {
+            // qDebug() << "Hard disk status rawValue is empty, adding empty rawValue item.";
             itemList << new QStandardItem("-");
         }
 
         if (!hardDiskStatusInfo.m_attributeName.isEmpty()) {
             itemList << new QStandardItem(hardDiskStatusInfo.m_attributeName);
         } else {
+            // qDebug() << "Hard disk status attributeName is empty, adding empty attributeName item.";
             itemList << new QStandardItem("-");
         }
 
         m_standardItemModel->appendRow(itemList);
+        // qDebug() << "Appended row to standard item model.";
     }
 
     DFrame *tableWidget = new DFrame;
@@ -346,25 +369,34 @@ void DiskHealthDetectionDialog::initUI()
 //    addContent(tableWidget);
 //    addSpacing(10);
 //    addContent(bottomWidget);
+
+    qDebug() << "DiskHealthDetectionDialog UI initialization complete.";
 }
 
 void DiskHealthDetectionDialog::initConnections()
 {
+    qDebug() << "Initializing connections for DiskHealthDetectionDialog.";
     connect(m_linkButton, &DCommandLinkButton::clicked, this, &DiskHealthDetectionDialog::onExportButtonClicked);
 #if QT_VERSION_MAJOR > 5
+    qDebug() << "Connecting themeTypeChanged signal for Qt6 or higher.";
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &DiskHealthDetectionDialog::onHandleChangeTheme);
 #else
+    qDebug() << "Connecting themeTypeChanged signal for Qt5.";
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, this, &DiskHealthDetectionDialog::onHandleChangeTheme);
 #endif
+    qDebug() << "Calling onHandleChangeTheme.";
     onHandleChangeTheme();
+    qDebug() << "Connections initialized for DiskHealthDetectionDialog.";
 }
 
 void DiskHealthDetectionDialog::onExportButtonClicked()
 {
+    qDebug() << "onExportButtonClicked called.";
     qInfo() << "Starting health info export for device:" << m_devicePath;
     //文件保存路径
     QString fileDirPath = QFileDialog::getSaveFileName(this, tr("Save File"), "CheckHealthInfo.txt", tr("Text files (*.txt)"));// 文件保存   硬盘健康检测信息   文件类型
     if (fileDirPath.isEmpty()) {
+        qDebug() << "File save path is empty, returning.";
         return;
     }
 
@@ -391,18 +423,22 @@ void DiskHealthDetectionDialog::onExportButtonClicked()
         DMessageManager::instance()->setContentMargens(this, QMargins(0, 0, 0, 20));
     } else {
         if (!fileDirPath.contains(".txt")) {
+            qDebug() << "Adding .txt extension to file path.";
             fileDirPath = fileDirPath + ".txt";
         }
 
         QFile file(fileDirPath);
         if (file.open(QIODevice::ReadWrite | QIODevice::Truncate)) {
+            qDebug() << "Successfully opened file for writing.";
             QTextStream out(&file);
 
             QString headers = tr("ID") + "," + tr("Status") + "," + tr("Current") + "," + tr("Worst")
                     + "," + tr("Threshold") + "," + tr("Raw Value") + "," + tr("Attribute name") + "\n";
             out << headers;
+            qDebug() << "Wrote headers to file.";
 
             for (int i = 0; i < m_standardItemModel->rowCount(); i++) {
+                // qDebug() << "Writing row:" << i << "to file.";
                 QString strInfo = m_standardItemModel->item(i, 0)->text() + ","
                         + m_standardItemModel->item(i, 1)->text() + ","
                         + m_standardItemModel->item(i, 2)->text() + ","
@@ -426,36 +462,48 @@ void DiskHealthDetectionDialog::onExportButtonClicked()
             DMessageManager::instance()->setContentMargens(this, QMargins(0, 0, 0, 20));
         }
     }
+    qDebug() << "onExportButtonClicked completed.";
 }
 
 bool DiskHealthDetectionDialog::event(QEvent *event)
 {
+    // qDebug() << "event called in DiskHealthDetectionDialog for event type:" << event->type();
     // 字体大小改变
     if (QEvent::ApplicationFontChange == event->type()) {
+        // qDebug() << "Application font change event detected.";
 #if QT_VERSION_MAJOR > 5
+        // qDebug() << "Adjusting link button width for Qt6 or higher.";
         m_linkButton->setFixedWidth(m_linkButton->fontMetrics().boundingRect(QString(tr("Export", "button"))).width());
 #else
+        // qDebug() << "Adjusting link button width for Qt5.";
         m_linkButton->setFixedWidth(m_linkButton->fontMetrics().width(QString(tr("Export", "button"))));
 #endif
 
         if (QApplication::font().pointSizeF() / 0.75 >= 18 ) {
+            qDebug() << "Font size is large, setting fixed size to 726x705.";
             setFixedSize(726, 705);
         } else {
+            qDebug() << "Font size is normal, setting fixed size to 726x700.";
             setFixedSize(726, 700);
         }
         DDialog::event(event);
     }
 
+    // qDebug() << "Event handling completed, returning DDialog::event result.";
     return DDialog::event(event);
 }
 
 void DiskHealthDetectionDialog::keyPressEvent(QKeyEvent *event)
 {
+    // qDebug() << "keyPressEvent called in DiskHealthDetectionDialog for key:" << event->key();
     if (event->key() == Qt::Key::Key_Escape) {
+        // qDebug() << "Escape key pressed, ignoring event.";
         event->ignore();
     } else {
+        // qDebug() << "Other key pressed, calling DDialog::keyPressEvent.";
         DDialog::keyPressEvent(event);
     }
+    // qDebug() << "keyPressEvent completed.";
 }
 
 void DiskHealthDetectionDialog::onHandleChangeTheme()
@@ -467,18 +515,22 @@ void DiskHealthDetectionDialog::onHandleChangeTheme()
 #if QT_VERSION_MAJOR > 5
     auto themeType = DGuiApplicationHelper::instance()->themeType();
     if (themeType == DGuiApplicationHelper::LightType) {
+        qDebug() << "Light theme detected.";
         valueColor = QColor("#000000");
         tableColor = QColor("#001A2E");
     } else if (themeType == DGuiApplicationHelper::DarkType) {
+        qDebug() << "Dark theme detected.";
         valueColor = QColor("#FFFFFF");
         tableColor = QColor("#C0C6D4");
     }
 #else
     auto themeType = DApplicationHelper::instance()->themeType();
     if (themeType == DApplicationHelper::LightType) {
+        qDebug() << "Light theme detected.";
         valueColor = QColor("#000000");
         tableColor = QColor("#001A2E");
     } else if (themeType == DApplicationHelper::DarkType) {
+        qDebug() << "Dark theme detected.";
         valueColor = QColor("#FFFFFF");
         tableColor = QColor("#C0C6D4");
     }
