@@ -11,25 +11,31 @@
 
 bool PolicyKitHelper::checkAuthorization(const QString& actionId, const QString& appBusName)
 {
-    if (appBusName.isEmpty())
+    if (appBusName.isEmpty()) {
+        qWarning() << "Empty appBusName provided for authorization check";
         return false;
+    }
 
     Authority::Result result;
     result = Authority::instance()->checkAuthorizationSync(actionId, SystemBusNameSubject(appBusName),
                                                            Authority::AllowUserInteraction);
     if (result == Authority::Yes) {
+        qDebug() << "Authorization granted for action:" << actionId;
         return true;
-    }else {
+    } else {
+        qWarning() << "Authorization denied for action:" << actionId;
         return false;
     }
 }
 
 PolicyKitHelper::PolicyKitHelper()
 {
+    qDebug() << "PolicyKitHelper instance created";
 
 }
 
 PolicyKitHelper::~PolicyKitHelper()
 {
+    qDebug() << "PolicyKitHelper instance destroyed";
 
 }
