@@ -2,7 +2,13 @@
 //
 // SPDX-License-Identifier: GPL-3.0-only
 
+#include <QtConfig>
+
+#if QT_VERSION_MAJOR > 5
+#include <polkit-qt6-1/PolkitQt1/Authority>
+#else
 #include <polkit-qt5-1/PolkitQt1/Authority>
+#endif
 
 using namespace PolkitQt1;
 
