@@ -26,12 +26,14 @@ FS EXT2::getFilesystemSupport()
     m_mkfsCmd = "mkfs." + Utils::fileSystemTypeToString(m_specificType);
     bool have_64bit_feature = false;
     if (!Utils::findProgramInPath(m_mkfsCmd).isEmpty()) {
+        qDebug() << "Found" << m_mkfsCmd << ", enabling create support";
         fs.create = FS::EXTERNAL;
         fs.create_with_label = FS::EXTERNAL;
 
         // Determine mkfs.ext4 version specific capabilities.
         m_forceAuto64bit = false;
         if (m_specificType == FS_EXT4) {
+            qDebug() << "Filesystem is ext4, checking version capabilities";
             Utils::executCmd(QString("%1%2").arg(m_mkfsCmd).arg(" -V"), output, error);
             int mke2fs_major_ver = 0;
             int mke2fs_minor_ver = 0;
@@ -39,6 +41,7 @@ FS EXT2::getFilesystemSupport()
             if (sscanf(output.toLatin1().data(), "mke2fs %d.%d.%d",
                        &mke2fs_major_ver, &mke2fs_minor_ver, &mke2fs_patch_ver)
                     >= 2) {
+                qDebug() << "mke2fs version:" << mke2fs_major_ver << "." << mke2fs_minor_ver << "." << mke2fs_patch_ver;
                 // Ext4 64bit feature was added in e2fsprogs 1.42, but
                 // only enable large volumes from 1.42.9 when a large
                 // number of 64bit bugs were fixed.
@@ -49,6 +52,7 @@ FS EXT2::getFilesystemSupport()
                 have_64bit_feature = (mke2fs_major_ver > 1)
                                      || (mke2fs_major_ver == 1 && mke2fs_minor_ver > 42)
                                      || (mke2fs_major_ver == 1 && mke2fs_minor_ver == 42 && mke2fs_patch_ver >= 9);
+                qDebug() << "64bit feature support:" << have_64bit_feature;
 
                 // (#766910) E2fsprogs 1.43 creates 64bit ext4 file
                 // systems by default.  RHEL/CentOS 7 configured e2fsprogs
@@ -60,45 +64,58 @@ FS EXT2::getFilesystemSupport()
                 // with 64bit ext4 file systems.
                 m_forceAuto64bit = (mke2fs_major_ver > 1)
                                    || (mke2fs_major_ver == 1 && mke2fs_minor_ver >= 42);
+                qDebug() << "Forcing auto 64bit:" << m_forceAuto64bit;
             }
         }
     }
 
     if (!Utils::findProgramInPath("dumpe2fs").isEmpty()) {
+        qDebug() << "dumpe2fs found, enabling read support";
         fs.read = FS::EXTERNAL;
         fs.online_read = FS::EXTERNAL;
     }
 
     if (!Utils::findProgramInPath("tune2fs").isEmpty()) {
+        qDebug() << "tune2fs found, enabling uuid read/write support";
         fs.read_uuid = FS::EXTERNAL;
         fs.write_uuid = FS::EXTERNAL;
     }
 
     if (!Utils::findProgramInPath("e2label").isEmpty()) {
+        qDebug() << "e2label found, enabling label read/write support";
         fs.read_label = FS::EXTERNAL;
         fs.write_label = FS::EXTERNAL;
     }
 
-    if (!Utils::findProgramInPath("e2fsck").isEmpty())
+    if (!Utils::findProgramInPath("e2fsck").isEmpty()) {
+        qDebug() << "e2fsck found, enabling check support";
         fs.check = FS::EXTERNAL;
+    }
 
     if (!Utils::findProgramInPath("resize2fs").isEmpty()) {
+        qDebug() << "resize2fs found, enabling grow support";
         fs.grow = FS::EXTERNAL;
 
-        if (fs.read) // Needed to determine a min file system size..
+        if (fs.read) { // Needed to determine a min file system size..
+            qDebug() << "read support found, enabling shrink support";
             fs.shrink = FS::EXTERNAL;
+        }
     }
 
     if (fs.check) {
+        qDebug() << "check support found, enabling copy/move";
         fs.copy = fs.move = FS::GPARTED;
 
         // If supported, use e2image to copy/move the file system as it only
         // copies used blocks, skipping unused blocks.  This is more efficient
         // than copying all blocks used by GParted's internal method.
         if (!Utils::findProgramInPath("e2image").isEmpty()) {
+            qDebug() << "e2image found, checking for -o src_offset support";
             Utils::executCmd("e2image", output, error);
-            if (Utils::regexpLabel(output, "(-o src_offset)") == "-o src_offset")
+            if (Utils::regexpLabel(output, "(-o src_offset)") == "-o src_offset") {
+                qDebug() << "e2image supports -o src_offset, using it for copy/move";
                 fs.copy = fs.move = FS::EXTERNAL;
+            }
         }
     }
     // Maximum size of an ext2/3/4 volume is 2^32 - 1 blocks, except for ext4 with
@@ -109,8 +126,10 @@ FS EXT2::getFilesystemSupport()
     // and Resize/Move dialogs should limit FS correctly without this.  See bug
     // #766910 comment #12 onwards for further discussion.
     //     https://bugzilla.gnome.org/show_bug.cgi?id=766910#c12
-    if (m_specificType == FS_EXT2 || m_specificType == FS_EXT3 || (m_specificType == FS_EXT4 && !have_64bit_feature))
+    if (m_specificType == FS_EXT2 || m_specificType == FS_EXT3 || (m_specificType == FS_EXT4 && !have_64bit_feature)) {
+        qDebug() << "Setting max filesystem size for non-64bit ext4 or ext2/3";
         m_fsLimits.max_size = Utils::floorSize(16 * TEBIBYTE - 4 * KIBIBYTE, MEBIBYTE);
+    }
 
     return fs;
 }
@@ -125,6 +144,7 @@ void EXT2::setUsedSectors(Partition &partition)
         strmatch = ("Block count:");
         int index = output.indexOf(strmatch);
         if (index >= 0 && index < output.length()) {
+            qDebug() << "Found block count";
             m_totalNumOfBlock = Utils::regexpLabel(output, QString("(?<=Block count:).*(?=\n)")).trimmed().toLong();
         }
 //        qDebug() << output;
@@ -132,36 +152,47 @@ void EXT2::setUsedSectors(Partition &partition)
         strmatch = ("Block size:");
         index = output.indexOf(strmatch);
         if (index >= 0 && index < output.length()) {
+            qDebug() << "Found block size";
             m_blocksSize = Utils::regexpLabel(output, QString("(?<=Block size:).*(?=\n)")).trimmed().toLong();
         }
 //        qDebug() << output << output.mid(index, strmatch.length()).toLatin1() << m_blocksSize;
 
         if (partition.m_busy) {
+            qDebug() << "Partition is busy, getting usage from mounted filesystem";
             Byte_Value fs_all;
             Byte_Value fs_free;
             if (Utils::getMountedFileSystemUsage(partition.getMountPoint(), fs_all, fs_free) == 0) {
+                qDebug() << "Successfully got mounted filesystem usage";
                 partition.setSectorUsage(qRound64(fs_all / double(partition.m_sectorSize)), qRound64(fs_free / double(partition.m_sectorSize)));
                 partition.m_fsBlockSize = m_blocksSize;
             }
         } else {
+            qDebug() << "Partition is not busy, estimating minimum size";
             // Resize2fs won't shrink a file system smaller than it's own
             // estimated minimum size, so use that to derive the free space.
             m_numOfFreeOrUsedBlocks = -1;
             if (!Utils::executCmd(QString("resize2fs -P %1").arg(partition.getPath()), output, error)) {
+                qDebug() << "resize2fs -P successful";
                 if (sscanf(output.toLatin1(), "Estimated minimum size of the filesystem: %lld", &m_numOfFreeOrUsedBlocks) == 1
-                        || sscanf(output.toStdString().c_str(), "预计文件系统的最小尺寸：%lld", &m_numOfFreeOrUsedBlocks) == 1)
+                        || sscanf(output.toStdString().c_str(), "预计文件系统的最小尺寸：%lld", &m_numOfFreeOrUsedBlocks) == 1) {
+                    qDebug() << "Parsed estimated minimum size";
                     m_numOfFreeOrUsedBlocks = m_totalNumOfBlock - m_numOfFreeOrUsedBlocks;
+                }
             }
             // Resize2fs can fail reporting please run fsck first.  Fall back
             // to reading dumpe2fs output for free space.
             if (m_numOfFreeOrUsedBlocks == -1) {
+                qDebug() << "resize2fs -P failed or did not provide minimum size, falling back to dumpe2fs";
                 strmatch = "Free blocks:";
                 index = output.indexOf(strmatch);
-                if (index < output.length())
+                if (index < output.length()) {
+                    qDebug() << "Found free blocks in dumpe2fs output";
                     sscanf(output.mid(index, strmatch.length()).toLatin1(), "Free blocks: %lld", &m_numOfFreeOrUsedBlocks);
+                }
             }
 
             if (m_totalNumOfBlock > -1 && m_numOfFreeOrUsedBlocks > -1 && m_blocksSize > -1) {
+                qDebug() << "Calculating and setting sector usage from block counts";
                 m_totalNumOfBlock = qRound64(m_totalNumOfBlock * (m_blocksSize / double(partition.m_sectorSize)));
                 m_numOfFreeOrUsedBlocks = qRound64(m_numOfFreeOrUsedBlocks * (m_blocksSize / double(partition.m_sectorSize)));
                 qDebug() << "111111111111111111111111" << m_totalNumOfBlock << m_numOfFreeOrUsedBlocks << m_blocksSize;
@@ -223,15 +254,20 @@ bool EXT2::create(const Partition &new_partition)
         // (#766910) Manually implement mke2fs.conf(5) auto_64-bit_support option
         // by setting or clearing the 64bit feature on the command line depending
         // of the partition size.
-        if (new_partition.getByteLength() >= 16 * TEBIBYTE)
+        if (new_partition.getByteLength() >= 16 * TEBIBYTE) {
+            qDebug() << "Partition is >= 16TiB, forcing 64bit feature";
             features = " -O 64bit";
-        else
+        } else {
+            qDebug() << "Partition is < 16TiB, forcing no 64bit feature";
             features = " -O ^64bit";
+        }
     }
     QString strlabel = new_partition.getFileSystemLabel();
     if (strlabel == " ") {
+        qDebug() << "Label is a single space, creating without label";
         cmd = QString("%1%2%3%4%5").arg(m_mkfsCmd).arg(" -F").arg(features).arg(" ").arg(new_partition.getPath());
     } else {
+        qDebug() << "Label is not a single space, creating with label if not empty";
         strlabel = strlabel.isEmpty() ? strlabel : QString(" -L %1").arg(strlabel);
         cmd = QString("%1%2%3%4%5%6").arg(m_mkfsCmd).arg(" -F").arg(features).arg(strlabel).arg(" ").arg(new_partition.getPath());
     }
@@ -256,24 +292,29 @@ G=1024*1024*1024
 */
 bool EXT2::resize(const Partition &partitionNew, bool fillPartition)
 {
+    qDebug() << "EXT2::resize(Partition) BEGIN";
     double d = Utils::sectorToUnit(partitionNew.getSectorLength(), partitionNew.m_sectorSize, UNIT_KIB);
     return resize(partitionNew.getPath(), QString::number(((long long)d)), fillPartition);
 }
 
 bool EXT2::resize(const QString &path, const QString &size, bool fillPartition)
 {
+    qDebug() << "EXT2::resize(path, size) BEGIN";
     QString str_temp = QString("resize2fs -p %1").arg(path);
 
     if (!fillPartition) {
+        qDebug() << "fillPartition is false";
         str_temp = QString("%1 %2K").arg(str_temp).arg(size);
     }
     QString output, error;
     int exitcode = Utils::executCmd(str_temp, output, error);
+    qDebug() << "EXT2::resize(path, size) END";
     return  0 == exitcode || 0 == error.compare("Unknown error");
 }
 
 bool EXT2::checkRepair(const Partition &partition)
 {
+    qDebug() << "Checking/repairing ext2/3/4 filesystem on partition:" << partition.getPath();
     return checkRepair(partition.getPath());
 }
 
@@ -288,52 +329,63 @@ bool EXT2::checkRepair(const QString &devpath)
 
 FS_Limits EXT2::getFilesystemLimits(const Partition &partition)
 {
+    qDebug() << "EXT2::getFilesystemLimits(Partition) BEGIN";
     return getFilesystemLimits(partition.getPath());
 }
 
 FS_Limits EXT2::getFilesystemLimits(const QString &path)
 {
+    qDebug() << "EXT2::getFilesystemLimits(path) BEGIN";
     m_fsLimits = FS_Limits{-1, -1};
     QString output, error;
     int exitcode = Utils::executCmd(QString("e2fsck -f %1").arg(path), output, error);
     if (exitcode != 0 && error.compare("Unknown error") != 0) {
+        qDebug() << "e2fsck failed, return";
         return m_fsLimits;
     }
 
 
     auto getNumber = [ = ](QString cmd, QString split1, QString split2)->long long{
+        qDebug() << "getNumber BEGIN";
         QString output, error;
         int exitcode = Utils::executCmd(cmd, output, error);
         if (exitcode != 0 && error.compare("Unknown error") != 0) {
+            qDebug() << "executCmd failed, return -1";
             return -1;
         }
 
         foreach (QString str, output.split("\n"))
         {
             if (str.contains(split1)) {
+                // qDebug() << "found split1";
                 auto list = str.split(split2);
                 if (list.count() == 2) {
+                    qDebug() << "found split2, return value";
                     return list[1].trimmed().toLongLong();
                 }
             }
         }
+        qDebug() << "getNumber END, return -1";
         return -1;
     };
 
     long long blockSize = getNumber(QString("tune2fs -l %1").arg(path), "Block size:", ":");
 
     if (-1 == blockSize) {
+        qDebug() << "blockSize is -1, return";
         return m_fsLimits;
     }
     long long blockCount = getNumber(QString("resize2fs -P %1").arg(path), "Estimated minimum size of the filesystem:", ":");
 
     if (-1 == blockCount) {
+        qDebug() << "blockCount is -1, return";
         return m_fsLimits;
     }
 
     m_fsLimits.max_size = 0;
     m_fsLimits.min_size = blockSize * blockCount;
 
+    qDebug() << "EXT2::getFilesystemLimits(path) END";
     return m_fsLimits;
 }
 
