@@ -24,20 +24,25 @@ Partition *Partition::clone() const
 
 bool Partition::sectorUsageKnown() const
 {
+    qDebug() << "Checking if sector usage is known";
     return m_sectorsUsed >= 0 && m_sectorsUnused >= 0;
 }
 
 Sector Partition::getSectorsUnallocated() const
 {
+    qDebug() << "Getting unallocated sectors";
     if (m_sectorsUnallocated < m_significantThreshold) {
+        qDebug() << "Unallocated sectors less than threshold, returning 0";
         return 0;
     } else {
+        qDebug() << "Returning unallocated sectors:" << m_sectorsUnallocated;
         return m_sectorsUnallocated;
     }
 }
 
 void Partition::reset()
 {
+    qDebug() << "Resetting partition data";
     m_path.clear();
     m_status = STAT_REAL;
     m_type = TYPE_UNALLOCATED;
@@ -67,6 +72,7 @@ void Partition::reset()
 
 void Partition::reset(const PartitionInfo &info)
 {
+    qDebug() << "Resetting partition with PartitionInfo";
     m_status = static_cast<PartitionStatus>(info.m_status);
     m_type = static_cast<PartitionType>(info.m_type);
     m_alignment = static_cast<PartitionAlignment>(info.m_alignment);
@@ -94,6 +100,7 @@ void Partition::reset(const PartitionInfo &info)
 
 void Partition::set(const QString &devicePath, const QString &partition, int partitionNumber, PartitionType type, FSType fstype, Sector sectorStart, Sector sectorEnd, Byte_Value sectorSize, bool insideExtended, bool busy)
 {
+    qDebug() << "set partition entry";
     m_devicePath = devicePath;
     m_path = partition;
     m_partitionNumber = partitionNumber;
@@ -112,11 +119,18 @@ void Partition::set(const QString &devicePath, const QString &partition, int par
 
     SupportedFileSystems s;
     FileSystem *fs =  s.getFsObject(m_fstype);
-    m_fsLimits = fs ? fs->getFilesystemLimits(*this) : FS_Limits{-1, -1}; //-1 -1 no support fileSystem  0 =>no limits
+    if (fs) {
+        qDebug() << "FileSystem object found, getting limits";
+        m_fsLimits = fs->getFilesystemLimits(*this);
+    } else {
+        qDebug() << "FileSystem object not found, setting default limits";
+        m_fsLimits = FS_Limits{-1, -1};
+    }
 }
 
 void Partition::setUnpartitioned(const QString &devicePath, const QString &partitionPath, FSType fstype, Sector length, Byte_Value sectorSize, bool busy)
 {
+    qDebug() << "setUnpartitioned entry";
     reset();
     // The path from the parent Device object and this child Partition object
     // spanning the whole device would appear to be the same.  However the former
@@ -162,12 +176,15 @@ void Partition::setUnallocated(const QString &devicePath, Sector sectorStart, Se
 
 bool Partition::filesystemLabelKnown() const
 {
+    qDebug() << "Checking if filesystem label is known";
     return m_haveFileSystemLabel;
 }
 
 void Partition::setFilesystemLabel(const QString &filesystemLabel)
 {
+    qDebug() << "Setting filesystem label:" << filesystemLabel;
     if (!filesystemLabel.isEmpty()) {
+        qDebug() << "Filesystem label is not empty, setting it";
         m_filesystemLabel = filesystemLabel;
         m_haveFileSystemLabel = true;
     }
@@ -180,38 +197,48 @@ void Partition::setFilesystemLabel(const QString &filesystemLabel)
 
 void Partition::addMountPoints(const QVector<QString> &mountpoints)
 {
+    qDebug() << "Adding mount points";
     m_mountpoints = mountpoints;
 }
 
 QVector<QString> Partition::getMountPoints() const
 {
+    qDebug() << "Getting mount points";
     return m_mountpoints;
 }
 
 QString Partition::getMountPoint() const
 {
+    qDebug() << "Getting single mount point";
     if (m_mountpoints.size() > 0) {
+        qDebug() << "Mount points exist, returning the first one";
         return m_mountpoints.front();
     }
 
+    qDebug() << "No mount points, returning empty string";
     return "";
 }
 
 void Partition::setSectorUsage(Sector sectorsFsSize, Sector sectorsFsUnused)
 {
+    qDebug() << "setSectorUsage entry";
     Sector length = getSectorLength();
     qDebug() << "Setting sector usage, partition length:" << length;
     if (0 <= sectorsFsSize && sectorsFsSize <= length
             && 0 <= sectorsFsUnused && sectorsFsUnused <= sectorsFsSize) {
+        qDebug() << "Valid sector usage data provided";
         m_sectorsUsed = sectorsFsSize - sectorsFsUnused;
         m_sectorsUnused = sectorsFsUnused;
         m_sectorsUnallocated = length - sectorsFsSize;
         m_significantThreshold = calcSignificantUnallocatedSectors();
     } else if (sectorsFsSize == -1) {
+        qDebug() << "sectorsFsSize is -1, calculating usage differently";
         if (0 <= sectorsFsUnused && sectorsFsUnused <= length) {
+            qDebug() << "Valid sectorsFsUnused";
             m_sectorsUsed = length - sectorsFsUnused;
             m_sectorsUnused = sectorsFsUnused;
         } else {
+            qDebug() << "Invalid sectorsFsUnused";
             m_sectorsUsed = -1;
             m_sectorsUnused = -1;
         }
@@ -222,32 +249,42 @@ void Partition::setSectorUsage(Sector sectorsFsSize, Sector sectorsFsUnused)
 
 Byte_Value Partition::getByteLength() const
 {
+    qDebug() << "Getting byte length";
     if (getSectorLength() >= 0) {
+        qDebug() << "Sector length is valid, calculating byte length";
         return getSectorLength() * m_sectorSize;
     } else {
+        qDebug() << "Sector length is invalid, returning -1";
         return -1;
     }
 }
 
 Sector Partition::getSectorLength() const
 {
+    qDebug() << "Getting sector length";
     if (m_sectorStart >= 0 && m_sectorEnd >= 0 && m_sectorEnd < LLONG_MAX) {
+        qDebug() << "Start and end sectors are valid";
         return m_sectorEnd - m_sectorStart + 1;
     } else {
+        qDebug() << "Start or end sectors are invalid, returning -1";
         return -1;
     }
 }
 
 QString Partition::getFileSystemLabel() const
 {
+    qDebug() << "Getting filesystem label";
     if (m_haveFileSystemLabel) {
+        qDebug() << "Filesystem label is known, returning it";
         return m_filesystemLabel;
     }
+    qDebug() << "Filesystem label is not known, returning empty string";
     return "";
 }
 
 PartitionInfo Partition::getPartitionInfo() const
 {
+    qDebug() << "Getting partition info";
     PartitionInfo info;
     info.m_devicePath = m_devicePath;
     info.m_partitionNumber = m_partitionNumber;
@@ -283,6 +320,7 @@ PartitionInfo Partition::getPartitionInfo() const
 
 Sector Partition::calcSignificantUnallocatedSectors() const
 {
+    qDebug() << "Calculating significant unallocated sectors";
     const double HIGHERUNALLOCATEDFRACTION = 0.05;
     const double LOWERUNALLOCATEDFRACTION = 0.02;
     Sector length = getSectorLength();
@@ -290,20 +328,28 @@ Sector Partition::calcSignificantUnallocatedSectors() const
     Sector significant;
 
     if (byteLen <= 0) {
+        qDebug() << "byteLen <= 0, setting significant to 1";
         significant = 1;
     } else if (byteLen <= 100 * MEBIBYTE) {
+        qDebug() << "byteLen <= 100MiB, using higher fraction";
         significant = qRound(length * HIGHERUNALLOCATEDFRACTION);
     } else if (byteLen <= 1 * GIBIBYTE) {
+        qDebug() << "byteLen <= 1GiB, calculating fraction";
         double fraction = (HIGHERUNALLOCATEDFRACTION - LOWERUNALLOCATEDFRACTION) - (byteLen - 100 * MEBIBYTE) * (HIGHERUNALLOCATEDFRACTION - LOWERUNALLOCATEDFRACTION) / (1 * GIBIBYTE - 100 * MEBIBYTE) + LOWERUNALLOCATEDFRACTION;
         significant = qRound(length * fraction);
     } else {
+        qDebug() << "byteLen > 1GiB, using lower fraction";
         significant = qRound(length * LOWERUNALLOCATEDFRACTION);
     }
 
+    qDebug() << "Calculated significant sectors (before check):" << significant;
+
     if (significant <= 1) {
+        qDebug() << "Significant sectors <= 1, setting to 1";
         significant = 1;
     }
 
+    qDebug() << "Final significant sectors:" << significant;
     return significant;
 }
 
